==> cloud-3.0.0-rc1.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Plugin/cloud/config/OpenStackCloudConfigPlugin.php <==
<?php

namespace Drupal\openstack\Plugin\cloud\config;

use Drupal\aws_cloud\Plugin\cloud\config\AwsCloudConfigPlugin;

/**
 * OpenStack cloud service provider (CloudConfig) plugin class.
 */
class OpenStackCloudConfigPlugin extends AwsCloudConfigPlugin {

  /**
   * {@inheritdoc}
   */
  public function getInstanceCollectionTemplateName() {
    return 'view.openstack_instance.list';
  }

  /**
   * {@inheritdoc}
   */
  public function loadCredentials($cloud_context) {
    /** @var \Drupal\cloud\Entity\CloudConfig $entity */
    $entity = $this->loadConfigEntity($cloud_context);
    $credentials = [];
    $openstack_ec2_api = $entity->get('field_use_openstack_ec2_api')->value;

    if (empty($openstack_ec2_api) && $entity !== FALSE) {
      $credentials = [
        'authUrl'           => $entity->get('field_api_endpoint')->value,
        'region'            => $entity->get('field_os_region')->value,
        'username'          => $entity->get('field_username')->value,
        'password'          => $entity->get('field_password')->value,
        'user_id'           => $entity->get('field_access_key')->value,
        'user_password'     => $entity->get('field_secret_key')->value,
        'api_endpoint_port' => $entity->get('field_api_endpoint_port')->value,
        'compute_version'   => $entity->get('field_compute_version')->value,
        'image_version'     => $entity->get('field_image_version')->value,
        'volume_version'    => $entity->get('field_volume_version')->value,
        'network_version'   => $entity->get('field_network_version')->value,
        'domain_id'         => $entity->get('field_domain_id')->value,
        'project_id'        => $entity->get('field_project_id')->value,
      ];

    }
    elseif ($entity !== FALSE) {
      $credentials = [
        'region'   => $entity->get('field_os_region')->value,
        'endpoint' => $entity->get('field_api_endpoint')->value,
        'ini_file' => $this->fileSystem->realpath(aws_cloud_ini_file_path($entity->get('cloud_context')->value)),
      // @todo this is hard-coded.
        'version'  => 'latest',
      ];
    }

    return $credentials;
  }

  /**
   * {@inheritdoc}
   */
  public function getPricingPageRoute() {
    return '';
  }

}

==> cloud-3.2.0.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Plugin/cloud/config/OpenStackCloudConfigPlugin.php <==
<?php

namespace Drupal\openstack\Plugin\cloud\config;

use Drupal\aws_cloud\Plugin\cloud\config\AwsCloudConfigPlugin;

/**
 * OpenStack cloud service provider (CloudConfig) plugin class.
 */
class OpenStackCloudConfigPlugin extends AwsCloudConfigPlugin {

  /**
   * {@inheritdoc}
   */
  public function getInstanceCollectionTemplateName(): string {
    return 'view.openstack_instance.list';
  }

  /**
   * {@inheritdoc}
   */
  public function loadCredentials($cloud_context): array {
    /** @var \Drupal\cloud\Entity\CloudConfig $entity */
    $entity = $this->loadConfigEntity($cloud_context);
    $credentials = [];
    $openstack_ec2_api = $entity->get('field_use_openstack_ec2_api')->value;

    if (empty($openstack_ec2_api) && $entity !== FALSE) {
      $credentials = [
        'authUrl'           => $entity->get('field_api_endpoint')->value,
        'region'            => $entity->get('field_os_region')->value,
        'username'          => $entity->get('field_username')->value,
        'password'          => $entity->get('field_password')->value,
        'user_id'           => $entity->get('field_access_key')->value,
        'user_password'     => $entity->get('field_secret_key')->value,
        'api_endpoint_port' => $entity->get('field_api_endpoint_port')->value,
        'compute_version'   => $entity->get('field_compute_version')->value,
        'image_version'     => $entity->get('field_image_version')->value,
        'volume_version'    => $entity->get('field_volume_version')->value,
        'network_version'   => $entity->get('field_network_version')->value,
        'domain_id'         => $entity->get('field_domain_id')->value,
        'project_id'        => $entity->get('field_project_id')->value,
      ];

    }
    elseif ($entity !== FALSE) {
      $credentials = [
        'region'   => $entity->get('field_os_region')->value,
        'endpoint' => $entity->get('field_api_endpoint')->value,
        'ini_file' => $this->fileSystem->realpath(aws_cloud_ini_file_path($entity->get('cloud_context')->value)),
      // @todo this is hard-coded.
        'version'  => 'latest',
      ];
    }

    return $credentials;
  }

  /**
   * {@inheritdoc}
   */
  public function getPricingPageRoute(): string {
    return '';
  }

}
